@@ -3,7 +3,7 @@ package Sah::Schema::currency::code;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Currency'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Locale::Codes::Currency_Codes ();
 
@@ -43,7 +43,17 @@ Sah::Schema::currency::code - Currency code
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::currency::code (from Perl distribution Sah-Schemas-Currency), released on 2020-03-02.
+This document describes version 0.005 of Sah::Schema::currency::code (from Perl distribution Sah-Schemas-Currency), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ ""  # INVALID
+
+ "idr"  # valid, becomes "IDR"
+
+ "foo"  # INVALID
 
 =head1 DESCRIPTION
 
